@@ -29,14 +29,16 @@ namespace kImageAnnotator {
 class ConfigNameHelper
 {
 public:
-	static QString annotator();
+	static QString kImageAnnotator();
 	static QString toolType();
 	static QString toolWidth(Tools tool);
 	static QString toolColor(Tools tool);
 	static QString toolTextColor(Tools tool);
 	static QString toolFillType(Tools tool);
-	static QString toolFontSize(Tools tool);
+	static QString toolFont(Tools tool);
 	static QString obfuscateFactor(Tools tool);
+	static QString shadowEnabled(Tools tool);
+	static QString annotatorDockWidgetsState();
 };
 
 }
